@@ -22,7 +22,7 @@
 #  Imports:
 #-------------------------------------------------------------------------
 
-
+from __future__ import absolute_import
 
 from traits.api import (
     Any,
@@ -336,7 +336,8 @@ class GenericTableFilterRule(HasPrivateTraits):
         """ Clones a new object from this one, optionally copying only a
         specified set of traits."""
         return super(GenericTableFilterRule, self).clone_traits(
-            traits, memo, copy, **metadata).set(enabled=self.enabled, name=self.name)
+            traits, memo, copy, **metadata).trait_set(
+                enabled=self.enabled, name=self.name)
 
     #-------------------------------------------------------------------------
     #  Returns a description of the filter:
@@ -411,7 +412,10 @@ class GenericTableFilterRuleEnabledColumn(ObjectColumn):
     def get_value(self, object):
         """ Returns the traits editor of the column for a specified object.
         """
-        return ['', '==>'][object.enabled]
+        if hasattr(object, 'enabled') and object.enabled:
+            return u'\N{HEAVY CHECK MARK}'
+        else:
+            return ''
 
 #-------------------------------------------------------------------------
 #  'GenericTableFilterRuleAndOrColumn' class:
@@ -731,7 +735,7 @@ class MenuTableFilter(RuleTableFilter):
         if len(self.rules) == 0:
             self.rules = [GenericTableFilterRule(
                 filter=self,
-                name_editor=name_editor).set(
+                name_editor=name_editor).trait_set(
                 name=name)
                 for name in names]
             for rule in self.rules:
